. inc/common.sh

init
run_mysqld
load_sakila2

# Adding 10k rows

vlog "Adding initial rows to database..."

sakila2_numrow=100
sakila2_count=0
while [ "$sakila2_numrow" -gt "$sakila2_count" ]
do
	${MYSQL} ${MYSQL_ARGS} -e "insert into test values ($sakila2_count, $sakila2_numrow);" sakila2
	let "sakila2_count=sakila2_count+1"
done


vlog "Initial rows added"

# Full backup

# Full backup folder
mkdir -p $topdir/data/full
# Incremental data
mkdir -p $topdir/data/delta

vlog "Starting backup"

xtrabackup --datadir=$mysql_datadir --backup --target-dir=$topdir/data/full

vlog "Full backup done"

# Changing data in sakila

vlog "Making changes to database"

let "sakila2_count=sakila2_numrow+1"
let "sakila2_numrow=500"
while [ "$sakila2_numrow" -gt "sakila2_count" ]
do
	${MYSQL} ${MYSQL_ARGS} -e "insert into test values ($sakila2_count, $sakila2_numrow);" sakila2
	let "sakila2_count=sakila2_count+1"
done

vlog "Changes done"

# Saving the checksum of original table
checksum_a=`${MYSQL} ${MYSQL_ARGS} -Ns -e "checksum table test;" sakila2 | awk '{print $2}'`

vlog "Table checksum is $checksum_a"

vlog "Making incremental backup"

# Incremental backup
xtrabackup --datadir=$mysql_datadir --backup --target-dir=$topdir/data/delta --incremental-basedir=$topdir/data/full

vlog "Incremental backup done"
vlog "Preparing backup"

# Prepare backup
xtrabackup --datadir=$mysql_datadir --prepare --apply-log-only --target-dir=$topdir/data/full
vlog "Log applied to backup"
xtrabackup --datadir=$mysql_datadir --prepare --apply-log-only --target-dir=$topdir/data/full --incremental-dir=$topdir/data/delta
vlog "Delta applied to backup"
xtrabackup --datadir=$mysql_datadir --prepare --target-dir=$topdir/data/full
vlog "Data prepared for restore"

# removing rows
vlog "Table cleared"
${MYSQL} ${MYSQL_ARGS} -e "delete from test;" sakila2

# Restore backup

stop_mysqld

vlog "Copying files"

cd $topdir/data/full/
cp -r * --target-directory=$mysql_datadir
cd $mysql_datadir
chown -R mysql:mysql *
cd $topdir

vlog "Data restored"

run_mysqld

vlog "Cheking checksums"
checksum_b=`${MYSQL} ${MYSQL_ARGS} -Ns -e "checksum table test;" sakila2 | awk '{print $2}'`

if [ $checksum_a -ne $checksum_b  ]
then 
	vlog "Checksums are not equal"
	exit -1
fi

vlog "Checksums are OK"

stop_mysqld
clean
